==> xlnl-3.1.7.tar.gz: xlnl-3.1.7/src/ver.h <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: ver.h,v 1.48 2007/02/11 16:39:12 bowkenken Exp $
***************************************************************/

#ifndef	VER_H
#define	VER_H

#define	STR_FILE_NAME_GAME	"lnl"

#define	STR_GAME_TITLE	"L&L - Labyrinths & Legends"
#define	STR_VER_GAME	VERSION

#define	STR_SINCE	"1993"
#define	STR_LATEST	"2007"
#define	STR_AUTHOR	"YOSHIMURA Tomohiko"

#define	STR_WEB	"http://lnl.sourceforge.jp/"
#define	STR_E_MAIL	"bowkenken@users.sourceforge.jp"

#define	STR_TITLE_1	"Created by"
#define	STR_HANDLE_1	"BowKenKen"

#define	STR_TITLE_2	"Graphic Design"
#define	STR_HANDLE_2	"[RPG DOT], Whitecat, REFMAP"

#define	STR_TITLE_3	" "
#define	STR_HANDLE_3	"and kokusi(yujyu)"

#define	STR_TITLE_THANKS	"Special Thanks"
#define	STR_HANDLE_THANKS	"TeaMiKL, nnn and you"

#define	STR_FMT_COPYRIGHT	\
		"--------------------------------" \
		"--------------------------------\n" \
		"%s : version %s\n" \
		"Copyright (c) %s-%s %s All rights reserved.\n" \
		"\n" \
		"URL   : %s\n" \
		"E-mail: %s\n" \
		"\n" \
		"%20s  %s\n" \
		"%20s  %s\n" \
		"%20s  %s\n" \
		"%20s  %s\n" \
		"--------------------------------" \
		"--------------------------------\n" \
		""

#define	LS_STR_COPYRIGHT	\
		STR_GAME_TITLE, STR_VER_GAME, \
		STR_SINCE, STR_LATEST, STR_AUTHOR, \
		STR_WEB, \
		STR_E_MAIL, \
		STR_TITLE_1, STR_HANDLE_1, \
		STR_TITLE_2, STR_HANDLE_2, \
		STR_TITLE_3, STR_HANDLE_3, \
		STR_TITLE_THANKS, STR_HANDLE_THANKS

#endif	/* VER_H */

==> xlnl-3.3.3.tar.gz: xlnl-3.3.3/src/ver.h <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: ver.h,v 1.55 2008/04/25 04:10:04 bowkenken Exp $
***************************************************************/

#ifndef	VER_H
#define	VER_H

#define	STR_FILE_NAME_GAME	"lnl"

#define	STR_GAME_TITLE	"L&L - Labyrinths & Legends"
#define	STR_VER_GAME	VERSION

#define	STR_SINCE	"1993"
#define	STR_LATEST	"2008"
#define	STR_AUTHOR	"YOSHIMURA Tomohiko"

#define	STR_WEB	"http://lnl.sourceforge.jp/"
#define	STR_E_MAIL	"bowkenken@users.sourceforge.jp"

#define	STR_TITLE_1	"Created by"
#define	STR_HANDLE_1	"bowkenken"

#define	STR_TITLE_2	"Graphic Design"
#define	STR_HANDLE_2	"[RPG DOT], Whitecat, REFMAP"

#define	STR_TITLE_3	" "
#define	STR_HANDLE_3	"kokusi(yujyu), hiyo and URARA"

#define	STR_TITLE_THANKS	"Special Thanks"
#define	STR_HANDLE_THANKS	"t-oikawa, TeaMiKL, nnn and you"

#define	STR_FMT_COPYRIGHT	\
		"--------------------------------" \
		"--------------------------------\n" \
		"%s : version %s  \n" \
		"Copyright (c) %s-%s %s All rights reserved.\n" \
		"                                " \
		"                                \n" \
		"URL   : %-56s\n" \
		"E-mail: %-56s\n" \
		"                                " \
		"                                \n" \
		"%20s  %-42s\n" \
		"%20s  %-42s\n" \
		"%20s  %-42s\n" \
		"%20s  %-42s\n" \
		"--------------------------------" \
		"--------------------------------\n" \
		""

#define	LS_STR_COPYRIGHT	\
		STR_GAME_TITLE, STR_VER_GAME, \
		STR_SINCE, STR_LATEST, STR_AUTHOR, \
		STR_WEB, \
		STR_E_MAIL, \
		STR_TITLE_1, STR_HANDLE_1, \
		STR_TITLE_2, STR_HANDLE_2, \
		STR_TITLE_3, STR_HANDLE_3, \
		STR_TITLE_THANKS, STR_HANDLE_THANKS

#endif	/* VER_H */
